qbits.alia.spec

Basic specs for validation/instrumentation, atm this doesn't include gen in most cases, not sure it ever will

Basic specs for validation/instrumentation, atm this doesn't
include gen in most cases, not sure it ever will
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries